Implemented ScriptGetLogicalWidths.

diff --git a/dlls/usp10/usp10.c b/dlls/usp10/usp10.c
index c3b0a17..6f860e0 100644
--- a/dlls/usp10/usp10.c
+++ b/dlls/usp10/usp10.c
@@ -1553,6 +1553,39 @@ HRESULT WINAPI ScriptStringGetLogicalWidths(SCRIPT_STRING_ANALYSIS ssa, int *piD
 }
 
 /***********************************************************************
+ *      ScriptGetLogicalWidths (USP10.@)
+ *
+ * Returns logical widths from an analysis.
+ *
+ * PARAMS
+ *  psa          [I] analysis.
+ *  cChars       [I] count of logical code points in the run.
+ *  cGlyphs      [I] count of glyphs in the run.
+ *  piGlyphWidth [I] array of glyph advance widths.
+ *  pwLogClust   [I] array of logical clusters.
+ *  psva         [I] visual attributes.
+ *  piDx         [O] logical widths returned.
+ *
+ * RETURNS
+ *  Success: S_OK
+ *  Failure: a non-zero HRESULT.
+ */
+HRESULT WINAPI ScriptGetLogicalWidths(const SCRIPT_ANALYSIS *psa, int cChars, 
+ int cGlyphs, const int *piGlyphWidth, const WORD *pwLogClust,
+ const SCRIPT_VISATTR *psva, int *piDx)
+{
+    int i;
+
+    TRACE("%p, %d, %d, %p %p, %p, %p\n", psa, cChars, cGlyphs, piGlyphWidth, pwLogClust, psva, piDx);
+
+    for (i = 0; i < cGlyphs; i++)
+    {
+        piDx[i] = piGlyphWidth[i];
+    }
+    return S_OK;
+}
+
+/***********************************************************************
  *      ScriptStringValidate (USP10.@)
  *
  * Validate a string analysis.
diff --git a/dlls/usp10/usp10.spec b/dlls/usp10/usp10.spec
index df07f43..ac1506e 100644
--- a/dlls/usp10/usp10.spec
+++ b/dlls/usp10/usp10.spec
@@ -8,7 +8,7 @@
 @ stdcall ScriptGetCMap(ptr ptr ptr long long ptr)
 @ stdcall ScriptGetFontProperties(long ptr ptr)
 @ stdcall ScriptGetGlyphABCWidth(ptr ptr long ptr)
-@ stub ScriptGetLogicalWidths
+@ stdcall ScriptGetLogicalWidths(ptr long long ptr ptr ptr ptr)
 @ stdcall ScriptGetProperties(ptr long)
 @ stdcall ScriptIsComplex(wstr long long)
 @ stdcall ScriptItemize(wstr long long ptr ptr ptr ptr)
